@@ -4,12 +4,17 @@ use warnings;
 use base qw( Hoppy::Base );
 
 sub do_handle {
-    my $self = shift;
-    my $poe  = shift;
-    my $c    = $self->context;
-    my $session_id = $poe->session->ID; 
-    $c->{sessions}->{$session_id} = 1;
+    my $self       = shift;
+    my $poe        = shift;
+    my $c          = $self->context;
+    my $session_id = $poe->session->ID;
+
+    $c->{sessions}->{$session_id}       = 1;
     $c->{not_authorized}->{$session_id} = 1;
+
+    if ( my $hook = $c->hook->{client_connect} ) {
+        $hook->work( { poe => $poe } );
+    }
 }
 
 1;
