@@ -4,7 +4,18 @@ use warnings;
 use base qw( Hoppy::Base );
 
 sub do_handle {
-    my $self = shift;
+    my $self       = shift;
+    my $poe        = shift;
+    my $c          = $self->context;
+    my $session_id = $poe->session->ID;
+    my $user       = $c->room->fetch_user_from_session_id($session_id);
+    my $user_id;
+    if ($user) {
+        $user_id = $user->user_id;
+    }
+    if ( my $hook = $c->hook->{client_error} ) {
+        $hook->work( { poe => $poe, user_id => $user_id } );
+    }
 }
 
 1;
